@@ -24,9 +24,7 @@ static Rcairo_backend_def RcairoBackendDef_ = {
 };
 Rcairo_backend_def *RcairoBackendDef_xlib = &RcairoBackendDef_;
 
-#include <R.h>
 #include <R_ext/eventloop.h>
-#include <R_ext/GraphicsEngine.h>
 
 #include <X11/X.h>
 #include <X11/Xlib.h>
